==> django-froala-editor-0.8.0.tar.gz: django-froala-editor-0.8.0/froala_editor/static/froala_editor/js/langs/sv.js <==
/**
 * Swedish
 */

$.Editable.LANGS['sv'] = {
  translation: {
    "Bold": "Fetstil",
    "Italic": "Kursiv stil",
    "Underline": "Understruken",
    "Strikethrough": "Genomstruken",
    "Font Size": "Storlek",
    "Color": "F\u00e4rg",
    "Background Color": "Bakgrundsf\u00e4rg",
    "Text Color": "Textf\u00e4rg",
    "Format Block": "Format",
    "Normal": "Normal",
    "Paragraph": "Br\u00f6dtext",
    "Code": "Kod",
    "Quote": "Blockcitat",
    "Heading 1": "Rubrik 1",
    "Heading 2": "Rubrik 2",
    "Heading 3": "Rubrik 3",
    "Heading 4": "Rubrik 4",
    "Heading 5": "Rubrik 5",
    "Heading 6": "Rubrik 6",
    "Alignment": "Justering",
    "Align Left": "V\u00e4nsterst\u00e4ll",
    "Align Center": "Centrera",
    "Align Right": "H\u00f6gerst\u00e4ll",
    "Justify": "Justera",
    "Numbered List": "Nummerlista",
    "Bulleted List": "Punktlista",
    "Indent Less": "Minska indrag",
    "Indent More": "\u00d6ka indrag",
    "Select All": "Markera allt",
    "Insert Link": "Infoga l\u00e4nk",
    "Insert Image": "Infoga bild",
    "Insert Video": "Infoga video",
    "Undo": "\u00c5ngra",
    "Redo": "G\u00f6r om",
    "Show HTML": "Visa HTML",
    "Float Left": "V\u00e4nster",
    "Float None": "Ingen",
    "Float Right": "H\u00f6ger",
    "Replace Image": "Ers\u00e4tt bild",
    "Remove Image": "Ta bort bild",
    "Title": "Titel",
    "Insert image": "Infoga bild",
    "Drop image": "Sl\u00e4ppa bild",
    "or click": "eller klicka",
    "Enter URL": "Ange URL",
    "Please wait!": "V\u00e4nta!",
    "Are you sure? Image will be deleted.": "\u00c4r du s\u00e4ker? Bild kommer att raderas.",
    "UNLINK": "Ta bort l\u00e4nk",
    "Open in new tab": "\u00d6ppna i ny flik",
    "Type something": "Ange n\u00e5got",
    "Cancel": "Avbryt",
    "OK": "Ok",
    "Manage images": "Hantera bilder",
    "Delete": "Radera",
    "Font Family": "Teckensnitt",
    "Insert Horizontal Line": "Infoga horisontell linje"
  },
  direction: "ltr"
};

==> django-froala-editor-0.8.4.tar.gz: django-froala-editor-0.8.4/froala_editor/static/froala_editor/js/langs/sv.js <==
/*!
 * froala_editor v1.1.6 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Swedish
 */

$.Editable.LANGS['sv'] = {
  translation: {
    "Bold": "Fetstil",
    "Italic": "Kursiv stil",
    "Underline": "Understruken",
    "Strikethrough": "Genomstruken",
    "Font Size": "Storlek",
    "Color": "F\u00e4rg",
    "Background Color": "Bakgrundsf\u00e4rg",
    "Text Color": "Textf\u00e4rg",
    "Format Block": "Format",
    "Normal": "Normal",
    "Paragraph": "Br\u00f6dtext",
    "Code": "Kod",
    "Quote": "Blockcitat",
    "Heading 1": "Rubrik 1",
    "Heading 2": "Rubrik 2",
    "Heading 3": "Rubrik 3",
    "Heading 4": "Rubrik 4",
    "Heading 5": "Rubrik 5",
    "Heading 6": "Rubrik 6",
    "Alignment": "Justering",
    "Align Left": "V\u00e4nsterst\u00e4ll",
    "Align Center": "Centrera",
    "Align Right": "H\u00f6gerst\u00e4ll",
    "Justify": "Justera",
    "Numbered List": "Nummerlista",
    "Bulleted List": "Punktlista",
    "Indent Less": "Minska indrag",
    "Indent More": "\u00d6ka indrag",
    "Select All": "Markera allt",
    "Insert Link": "Infoga l\u00e4nk",
    "Insert Image": "Infoga bild",
    "Insert Video": "Infoga video",
    "Undo": "\u00c5ngra",
    "Redo": "G\u00f6r om",
    "Show HTML": "Visa HTML",
    "Float Left": "V\u00e4nster",
    "Float None": "Ingen",
    "Float Right": "H\u00f6ger",
    "Replace Image": "Ers\u00e4tt bild",
    "Remove Image": "Ta bort bild",
    "Title": "Titel",
    "Insert image": "Infoga bild",
    "Drop image": "Sl\u00e4ppa bild",
    "or click": "eller klicka",
    "Enter URL": "Ange URL",
    "Please wait!": "V\u00e4nta!",
    "Are you sure? Image will be deleted.": "\u00c4r du s\u00e4ker? Bild kommer att raderas.",
    "UNLINK": "Ta bort l\u00e4nk",
    "Open in new tab": "\u00d6ppna i ny flik",
    "Type something": "Ange n\u00e5got",
    "Cancel": "Avbryt",
    "OK": "Ok",
    "Manage images": "Hantera bilder",
    "Delete": "Radera",
    "Font Family": "Teckensnitt",
    "Insert Horizontal Line": "Infoga horisontell linje",
    "Table": "Tabell",
    "Insert table": "Infoga tabell",
    "Cell": "Cell",
    "Row": "Rad",
    "Column": "Kolumn",
    "Delete table": "Radera tabell",
    "Insert cell before": "Infoga cell innan",
    "Insert cell after": "Infoga cell efter",
    "Delete cell": "Radera cell",
    "Merge cells": "Sammanfoga celler",
    "Horizontal split": "Horisontell split",
    "Vertical split": "Vertikal split",
    "Insert row above": "Infoga rad f\u00f6re",
    "Insert row below": "Infoga rad efter",
    "Delete row": "Radera rad",
    "Insert column before": "Infoga kollumn f\u00f6re",
    "Insert column after": "Infoga kolumn efter",
    "Delete column": "Radera kolumn"
  },
  direction: "ltr"
};
